# Changelog

## v0.0.3 - 2024.2.24

**Improvement**:

- Remove all code used for initial project testing.

**New Features**:

- Read raster data from a file, convert the data into a Python list.
- Create a raster template based on the input raster, and replace the data from list into the new raster.
- Running CA models based on raster data to analyze population and other resource migration.

## v0.0.4 - 2024.3.18

**Improvement**:

- Modify the original code and comments.
- Add new Features.

**New Features**:

- Reads multiple raster data (.tif) from a folder and stores it in a dictionary.
- Reorganizes data from a list dictionary representing multiple raster data.